struct struct_x {
};

typedef struct_x x;

typedef struct struct_y {
} y;

typedef struct {
} z;

typedef int my_int;

typedef my_int int2;
typedef int2   int3;



typedef int loop2;
typedef loop2 loop2;

typedef old_type new_type;
typedef new_type old_type;

x v1;
y v2;
z v3;

my_int i1;
int2 i2;
int3 i3;


loop2 l2;

new_type t1;
old_type t2;
